# n8n Node Categories


## AI

- **Basic LLM Chain** (`@n8n/n8n-nodes-langchain.chainLlm`)
- **Chat Memory Manager** (`@n8n/n8n-nodes-langchain.memoryManager`)
- **Chat Messages Retriever** (`@n8n/n8n-nodes-langchain.memoryChatRetriever`)
- **Contextual Compression Retriever** (`@n8n/n8n-nodes-langchain.retrieverContextualCompression`)
- **Default Data Loader** (`@n8n/n8n-nodes-langchain.documentDefaultDataLoader`)
- **In Memory Vector Store Insert** (`@n8n/n8n-nodes-langchain.vectorStoreInMemoryInsert`)
- **In Memory Vector Store Load** (`@n8n/n8n-nodes-langchain.vectorStoreInMemoryLoad`)
- **MCP Server Trigger** (`@n8n/n8n-nodes-langchain.mcpTrigger`) (trigger)
- **MultiQuery Retriever** (`@n8n/n8n-nodes-langchain.retrieverMultiQuery`)
- **OpenAI Assistant** (`@n8n/n8n-nodes-langchain.openAiAssistant`)
- **OpenAI Model** (`@n8n/n8n-nodes-langchain.lmOpenAi`)
- **Vector Store Retriever** (`@n8n/n8n-nodes-langchain.retrieverVectorStore`)
- **Workflow Retriever** (`@n8n/n8n-nodes-langchain.retrieverWorkflow`)
- **Zep Vector Store: Insert** (`@n8n/n8n-nodes-langchain.vectorStoreZepInsert`)

## Analytics

- **Cortex** (`n8n-nodes-base.cortex`)
- **Grafana** (`n8n-nodes-base.grafana`)
- **Humantic AI** (`n8n-nodes-base.humanticAi`)
- **Marketstack** (`n8n-nodes-base.marketstack`)
- **Orbit** (`n8n-nodes-base.orbit`)
- **PostHog** (`n8n-nodes-base.postHog`)
- **ProfitWell** (`n8n-nodes-base.profitWell`)
- **SecurityScorecard** (`n8n-nodes-base.securityScorecard`)
- **Segment** (`n8n-nodes-base.segment`)

## Communication

- **AMQP Sender** (`n8n-nodes-base.amqp`)
- **AMQP Trigger** (`n8n-nodes-base.amqpTrigger`) (trigger)
- **Brevo** (`n8n-nodes-base.sendInBlue`)
- **Brevo Trigger** (`n8n-nodes-base.sendInBlueTrigger`) (trigger)
- **ClickUp** (`n8n-nodes-base.clickUp`)
- **ClickUp Trigger** (`n8n-nodes-base.clickUpTrigger`) (trigger)
- **Customer.io** (`n8n-nodes-base.customerIo`)
- **Customer.io Trigger** (`n8n-nodes-base.customerIoTrigger`) (trigger)
- **Demio** (`n8n-nodes-base.demio`)
- **Discourse** (`n8n-nodes-base.discourse`)
- **Disqus** (`n8n-nodes-base.disqus`)
- **E-goi** (`n8n-nodes-base.egoi`)
- **Emelia** (`n8n-nodes-base.emelia`)
- **Emelia Trigger** (`n8n-nodes-base.emeliaTrigger`) (trigger)
- **Form.io Trigger** (`n8n-nodes-base.formIoTrigger`) (trigger)
- **Formstack Trigger** (`n8n-nodes-base.formstackTrigger`) (trigger)
- **Freshdesk** (`n8n-nodes-base.freshdesk`)
- **GetResponse** (`n8n-nodes-base.getResponse`)
- **GetResponse Trigger** (`n8n-nodes-base.getResponseTrigger`) (trigger)
- **GoToWebinar** (`n8n-nodes-base.goToWebinar`)
- **Gotify** (`n8n-nodes-base.gotify`)
- **Hacker News** (`n8n-nodes-base.hackerNews`)
- **HaloPSA** (`n8n-nodes-base.haloPSA`)
- **Help Scout** (`n8n-nodes-base.helpScout`)
- **Help Scout Trigger** (`n8n-nodes-base.helpScoutTrigger`) (trigger)
- **Intercom** (`n8n-nodes-base.intercom`)
- **Iterable** (`n8n-nodes-base.iterable`)
- **Jotform Trigger** (`n8n-nodes-base.jotFormTrigger`) (trigger)
- **Keap** (`n8n-nodes-base.keap`)
- **Keap Trigger** (`n8n-nodes-base.keapTrigger`) (trigger)
- **KoBoToolbox** (`n8n-nodes-base.koBoToolbox`)
- **KoBoToolbox Trigger** (`n8n-nodes-base.koBoToolboxTrigger`) (trigger)
- **Line** (`n8n-nodes-base.line`)
- **LinkedIn** (`n8n-nodes-base.linkedIn`)
- **MQTT** (`n8n-nodes-base.mqtt`)
- **MSG91** (`n8n-nodes-base.msg91`)
- **Mailchimp** (`n8n-nodes-base.mailchimp`)
- **Mailchimp Trigger** (`n8n-nodes-base.mailchimpTrigger`) (trigger)
- **Mailgun** (`n8n-nodes-base.mailgun`)
- **Mailjet** (`n8n-nodes-base.mailjet`)
- **Mailjet Trigger** (`n8n-nodes-base.mailjetTrigger`) (trigger)
- **Matrix** (`n8n-nodes-base.matrix`)
- **Mautic** (`n8n-nodes-base.mautic`)
- **Mautic Trigger** (`n8n-nodes-base.mauticTrigger`) (trigger)
- **MessageBird** (`n8n-nodes-base.messageBird`)
- **Mocean** (`n8n-nodes-base.mocean`)
- **Monica CRM** (`n8n-nodes-base.monicaCrm`)
- **PagerDuty** (`n8n-nodes-base.pagerDuty`)
- **Plivo** (`n8n-nodes-base.plivo`)
- **Postmark Trigger** (`n8n-nodes-base.postmarkTrigger`) (trigger)
- **Pushbullet** (`n8n-nodes-base.pushbullet`)
- **Pushcut** (`n8n-nodes-base.pushcut`)
- **Pushcut Trigger** (`n8n-nodes-base.pushcutTrigger`) (trigger)
- **Pushover** (`n8n-nodes-base.pushover`)
- **Reddit** (`n8n-nodes-base.reddit`)
- **Redis Trigger** (`n8n-nodes-base.redisTrigger`) (trigger)
- **RocketChat** (`n8n-nodes-base.rocketchat`)
- **Rundeck** (`n8n-nodes-base.rundeck`)
- **SIGNL4** (`n8n-nodes-base.signl4`)
- **Salesforce** (`n8n-nodes-base.salesforce`)
- **Salesforce Trigger** (`n8n-nodes-base.salesforceTrigger`) (trigger)
- **SendGrid** (`n8n-nodes-base.sendGrid`)
- **Sendy** (`n8n-nodes-base.sendy`)
- **ServiceNow** (`n8n-nodes-base.serviceNow`)
- **Slack Trigger** (`n8n-nodes-base.slackTrigger`) (trigger)
- **SurveyMonkey Trigger** (`n8n-nodes-base.surveyMonkeyTrigger`) (trigger)
- **Telegram Trigger** (`n8n-nodes-base.telegramTrigger`) (trigger)
- **Twilio** (`n8n-nodes-base.twilio`)
- **Twilio Trigger** (`n8n-nodes-base.twilioTrigger`) (trigger)
- **Twist** (`n8n-nodes-base.twist`)
- **Typeform Trigger** (`n8n-nodes-base.typeformTrigger`) (trigger)
- **Vero** (`n8n-nodes-base.vero`)
- **Vonage** (`n8n-nodes-base.vonage`)
- **WhatsApp Trigger** (`n8n-nodes-base.whatsAppTrigger`) (trigger)
- **Wufoo Trigger** (`n8n-nodes-base.wufooTrigger`) (trigger)
- **Zammad** (`n8n-nodes-base.zammad`)
- **Zendesk** (`n8n-nodes-base.zendesk`)
- **Zendesk Trigger** (`n8n-nodes-base.zendeskTrigger`) (trigger)
- **Zoho CRM** (`n8n-nodes-base.zohoCrm`)
- **Zoom** (`n8n-nodes-base.zoom`)
- **Zulip** (`n8n-nodes-base.zulip`)
- **seven** (`n8n-nodes-base.sms77`)

## Core Nodes

- **AI Transform** (`n8n-nodes-base.aiTransform`)
- **Code** (`n8n-nodes-base.code`)
- **Compare Datasets** (`n8n-nodes-base.compareDatasets`)
- **Compression** (`n8n-nodes-base.compression`)
- **Convert to/from binary data** (`n8n-nodes-base.moveBinaryData`)
- **Cron** (`n8n-nodes-base.cron`) (trigger)
- **Data table** (`n8n-nodes-base.dataTable`)
- **Date & Time** (`n8n-nodes-base.dateTime`)
- **E2E Test** (`n8n-nodes-base.e2eTest`)
- **Error Trigger** (`n8n-nodes-base.errorTrigger`) (trigger)
- **Execute Command** (`n8n-nodes-base.executeCommand`)
- **Execution Data** (`n8n-nodes-base.executionData`)
- **Filter** (`n8n-nodes-base.filter`)
- **Git** (`n8n-nodes-base.git`)
- **HTML** (`n8n-nodes-base.html`)
- **HTML Extract** (`n8n-nodes-base.htmlExtract`)
- **HTTP Request** (`n8n-nodes-base.httpRequest`)
- **If** (`n8n-nodes-base.if`)
- **Interval** (`n8n-nodes-base.interval`) (trigger)
- **MCP Server Trigger** (`@n8n/n8n-nodes-langchain.mcpTrigger`) (trigger)
- **Manual Chat Trigger** (`@n8n/n8n-nodes-langchain.manualChatTrigger`) (trigger)
- **Manual Trigger** (`n8n-nodes-base.manualTrigger`) (trigger)
- **Markdown** (`n8n-nodes-base.markdown`)
- **No Operation, do nothing** (`n8n-nodes-base.noOp`)
- **RSS Feed Trigger** (`n8n-nodes-base.rssFeedReadTrigger`) (trigger)
- **RSS Read** (`n8n-nodes-base.rssFeedRead`)
- **Read Binary File** (`n8n-nodes-base.readBinaryFile`)
- **Read Binary Files** (`n8n-nodes-base.readBinaryFiles`)
- **Read PDF** (`n8n-nodes-base.readPDF`)
- **Rename Keys** (`n8n-nodes-base.renameKeys`)
- **SSE Trigger** (`n8n-nodes-base.sseTrigger`) (trigger)
- **SSH** (`n8n-nodes-base.ssh`)
- **Schedule Trigger** (`n8n-nodes-base.scheduleTrigger`) (trigger)
- **Sticky Note** (`n8n-nodes-base.stickyNote`)
- **Stop and Error** (`n8n-nodes-base.stopAndError`)
- **Switch** (`n8n-nodes-base.switch`)
- **TOTP** (`n8n-nodes-base.totp`)
- **Track Time Saved** (`n8n-nodes-base.timeSaved`)
- **Write Binary File** (`n8n-nodes-base.writeBinaryFile`)
- **XML** (`n8n-nodes-base.xml`)
- **iCalendar** (`n8n-nodes-base.iCal`)
- **n8n Form** (`n8n-nodes-base.form`) (trigger)

## Data & Storage

- **Airtable Trigger** (`n8n-nodes-base.airtableTrigger`) (trigger)
- **Baserow** (`n8n-nodes-base.baserow`)
- **Bitwarden** (`n8n-nodes-base.bitwarden`)
- **Box** (`n8n-nodes-base.box`)
- **Box Trigger** (`n8n-nodes-base.boxTrigger`) (trigger)
- **Compression** (`n8n-nodes-base.compression`)
- **CrateDB** (`n8n-nodes-base.crateDb`)
- **Dropbox** (`n8n-nodes-base.dropbox`)
- **ERPNext** (`n8n-nodes-base.erpNext`)
- **FileMaker** (`n8n-nodes-base.filemaker`)
- **GraphQL** (`n8n-nodes-base.graphql`)
- **Grist** (`n8n-nodes-base.grist`)
- **KoBoToolbox** (`n8n-nodes-base.koBoToolbox`)
- **KoBoToolbox Trigger** (`n8n-nodes-base.koBoToolboxTrigger`) (trigger)
- **MongoDB** (`n8n-nodes-base.mongoDb`)
- **Nextcloud** (`n8n-nodes-base.nextCloud`)
- **NocoDB** (`n8n-nodes-base.nocoDb`)
- **Odoo** (`n8n-nodes-base.odoo`)
- **PostBin** (`n8n-nodes-base.postBin`)
- **QuestDB** (`n8n-nodes-base.questDb`)
- **Quick Base** (`n8n-nodes-base.quickbase`)
- **Redis** (`n8n-nodes-base.redis`)
- **Redis Trigger** (`n8n-nodes-base.redisTrigger`) (trigger)
- **S3** (`n8n-nodes-base.s3`)
- **Snowflake** (`n8n-nodes-base.snowflake`)
- **Stackby** (`n8n-nodes-base.stackby`)
- **Storyblok** (`n8n-nodes-base.storyblok`)
- **Strapi** (`n8n-nodes-base.strapi`)
- **Supabase** (`n8n-nodes-base.supabase`)
- **TimescaleDB** (`n8n-nodes-base.timescaleDb`)
- **Unleashed Software** (`n8n-nodes-base.unleashedSoftware`)
- **uProc** (`n8n-nodes-base.uproc`)

## Developer Tools

- **Ldap** (`n8n-nodes-base.ldap`)

## Development

- **AI Transform** (`n8n-nodes-base.aiTransform`)
- **AMQP Sender** (`n8n-nodes-base.amqp`)
- **AMQP Trigger** (`n8n-nodes-base.amqpTrigger`) (trigger)
- **Airtop** (`n8n-nodes-base.airtop`)
- **Bitbucket Trigger** (`n8n-nodes-base.bitbucketTrigger`) (trigger)
- **Bubble** (`n8n-nodes-base.bubble`)
- **CircleCI** (`n8n-nodes-base.circleCi`)
- **Cloudflare** (`n8n-nodes-base.cloudflare`)
- **Cockpit** (`n8n-nodes-base.cockpit`)
- **Code** (`n8n-nodes-base.code`)
- **Cortex** (`n8n-nodes-base.cortex`)
- **CrateDB** (`n8n-nodes-base.crateDb`)
- **Customer.io** (`n8n-nodes-base.customerIo`)
- **Customer.io Trigger** (`n8n-nodes-base.customerIoTrigger`) (trigger)
- **Data table** (`n8n-nodes-base.dataTable`)
- **DebugHelper** (`n8n-nodes-base.debugHelper`)
- **Error Trigger** (`n8n-nodes-base.errorTrigger`) (trigger)
- **Execute Command** (`n8n-nodes-base.executeCommand`)
- **Execution Data** (`n8n-nodes-base.executionData`)
- **FileMaker** (`n8n-nodes-base.filemaker`)
- **Git** (`n8n-nodes-base.git`)
- **GitHub** (`n8n-nodes-base.github`) (trigger)
- **GitLab** (`n8n-nodes-base.gitlab`)
- **GitLab Trigger** (`n8n-nodes-base.gitlabTrigger`) (trigger)
- **Github Trigger** (`n8n-nodes-base.githubTrigger`) (trigger)
- **Grafana** (`n8n-nodes-base.grafana`)
- **GraphQL** (`n8n-nodes-base.graphql`)
- **HTTP Request** (`n8n-nodes-base.httpRequest`)
- **JWT** (`n8n-nodes-base.jwt`)
- **Jenkins** (`n8n-nodes-base.jenkins`)
- **Jira Software** (`n8n-nodes-base.jira`)
- **Jira Trigger** (`n8n-nodes-base.jiraTrigger`) (trigger)
- **Kafka** (`n8n-nodes-base.kafka`)
- **Kafka Trigger** (`n8n-nodes-base.kafkaTrigger`) (trigger)
- **Ldap** (`n8n-nodes-base.ldap`)
- **MISP** (`n8n-nodes-base.misp`)
- **MQTT** (`n8n-nodes-base.mqtt`)
- **MSG91** (`n8n-nodes-base.msg91`)
- **Mailgun** (`n8n-nodes-base.mailgun`)
- **Mailjet** (`n8n-nodes-base.mailjet`)
- **Mailjet Trigger** (`n8n-nodes-base.mailjetTrigger`) (trigger)
- **MongoDB** (`n8n-nodes-base.mongoDb`)
- **Netlify** (`n8n-nodes-base.netlify`)
- **Netlify Trigger** (`n8n-nodes-base.netlifyTrigger`) (trigger)
- **Npm** (`n8n-nodes-base.npm`)
- **PagerDuty** (`n8n-nodes-base.pagerDuty`)
- **Peekalink** (`n8n-nodes-base.peekalink`)
- **Plivo** (`n8n-nodes-base.plivo`)
- **PostBin** (`n8n-nodes-base.postBin`)
- **PostHog** (`n8n-nodes-base.postHog`)
- **Postgres Trigger** (`n8n-nodes-base.postgresTrigger`) (trigger)
- **Postmark Trigger** (`n8n-nodes-base.postmarkTrigger`) (trigger)
- **QuestDB** (`n8n-nodes-base.questDb`)
- **RabbitMQ** (`n8n-nodes-base.rabbitmq`)
- **Redis** (`n8n-nodes-base.redis`)
- **Redis Trigger** (`n8n-nodes-base.redisTrigger`) (trigger)
- **Rundeck** (`n8n-nodes-base.rundeck`)
- **S3** (`n8n-nodes-base.s3`)
- **SIGNL4** (`n8n-nodes-base.signl4`)
- **SSE Trigger** (`n8n-nodes-base.sseTrigger`) (trigger)
- **SSH** (`n8n-nodes-base.ssh`)
- **Segment** (`n8n-nodes-base.segment`)
- **Sentry.io** (`n8n-nodes-base.sentryIo`)
- **Taiga** (`n8n-nodes-base.taiga`)
- **Taiga Trigger** (`n8n-nodes-base.taigaTrigger`) (trigger)
- **TheHive** (`n8n-nodes-base.theHive`)
- **TheHive 5 Trigger** (`n8n-nodes-base.theHiveProjectTrigger`) (trigger)
- **TheHive Trigger** (`n8n-nodes-base.theHiveTrigger`) (trigger)
- **TimescaleDB** (`n8n-nodes-base.timescaleDb`)
- **Track Time Saved** (`n8n-nodes-base.timeSaved`)
- **TravisCI** (`n8n-nodes-base.travisCi`)
- **Twilio** (`n8n-nodes-base.twilio`)
- **Twilio Trigger** (`n8n-nodes-base.twilioTrigger`) (trigger)
- **UptimeRobot** (`n8n-nodes-base.uptimeRobot`)
- **urlscan.io** (`n8n-nodes-base.urlScanIo`)

## Finance & Accounting

- **Chargebee** (`n8n-nodes-base.chargebee`)
- **Chargebee Trigger** (`n8n-nodes-base.chargebeeTrigger`) (trigger)
- **CoinGecko** (`n8n-nodes-base.coinGecko`)
- **ERPNext** (`n8n-nodes-base.erpNext`)
- **Invoice Ninja** (`n8n-nodes-base.invoiceNinja`)
- **Invoice Ninja Trigger** (`n8n-nodes-base.invoiceNinjaTrigger`) (trigger)
- **Marketstack** (`n8n-nodes-base.marketstack`)
- **PayPal** (`n8n-nodes-base.payPal`)
- **PayPal Trigger** (`n8n-nodes-base.payPalTrigger`) (trigger)
- **QuickBooks Online** (`n8n-nodes-base.quickbooks`)
- **Stripe** (`n8n-nodes-base.stripe`)
- **Stripe Trigger** (`n8n-nodes-base.stripeTrigger`) (trigger)
- **Wise** (`n8n-nodes-base.wise`)
- **Wise Trigger** (`n8n-nodes-base.wiseTrigger`) (trigger)
- **Xero** (`n8n-nodes-base.xero`)

## Marketing

- **APITemplate.io** (`n8n-nodes-base.apiTemplateIo`)
- **Action Network** (`n8n-nodes-base.actionNetwork`)
- **ActiveCampaign** (`n8n-nodes-base.activeCampaign`)
- **ActiveCampaign Trigger** (`n8n-nodes-base.activeCampaignTrigger`) (trigger)
- **Agile CRM** (`n8n-nodes-base.agileCrm`)
- **Autopilot** (`n8n-nodes-base.autopilot`)
- **Autopilot Trigger** (`n8n-nodes-base.autopilotTrigger`) (trigger)
- **Bannerbear** (`n8n-nodes-base.bannerbear`)
- **Brevo** (`n8n-nodes-base.sendInBlue`)
- **Brevo Trigger** (`n8n-nodes-base.sendInBlueTrigger`) (trigger)
- **Cockpit** (`n8n-nodes-base.cockpit`)
- **ConvertKit** (`n8n-nodes-base.convertKit`)
- **ConvertKit Trigger** (`n8n-nodes-base.convertKitTrigger`) (trigger)
- **Copper** (`n8n-nodes-base.copper`)
- **E-goi** (`n8n-nodes-base.egoi`)
- **Emelia** (`n8n-nodes-base.emelia`)
- **Emelia Trigger** (`n8n-nodes-base.emeliaTrigger`) (trigger)
- **Facebook Lead Ads Trigger** (`n8n-nodes-base.facebookLeadAdsTrigger`) (trigger)
- **Facebook Trigger** (`n8n-nodes-base.facebookTrigger`) (trigger)
- **Freshworks CRM** (`n8n-nodes-base.freshworksCrm`)
- **GetResponse** (`n8n-nodes-base.getResponse`)
- **GetResponse Trigger** (`n8n-nodes-base.getResponseTrigger`) (trigger)
- **Ghost** (`n8n-nodes-base.ghost`)
- **Hacker News** (`n8n-nodes-base.hackerNews`)
- **Iterable** (`n8n-nodes-base.iterable`)
- **LinkedIn** (`n8n-nodes-base.linkedIn`)
- **Mailcheck** (`n8n-nodes-base.mailcheck`)
- **Mailchimp** (`n8n-nodes-base.mailchimp`)
- **Mailchimp Trigger** (`n8n-nodes-base.mailchimpTrigger`) (trigger)
- **Mautic** (`n8n-nodes-base.mautic`)
- **Mautic Trigger** (`n8n-nodes-base.mauticTrigger`) (trigger)
- **Medium** (`n8n-nodes-base.medium`)
- **Phantombuster** (`n8n-nodes-base.phantombuster`)
- **SendGrid** (`n8n-nodes-base.sendGrid`)
- **Sendy** (`n8n-nodes-base.sendy`)
- **Storyblok** (`n8n-nodes-base.storyblok`)
- **Strapi** (`n8n-nodes-base.strapi`)
- **SurveyMonkey Trigger** (`n8n-nodes-base.surveyMonkeyTrigger`) (trigger)
- **Webflow** (`n8n-nodes-base.webflow`)
- **Webflow Trigger** (`n8n-nodes-base.webflowTrigger`) (trigger)
- **Wordpress** (`n8n-nodes-base.wordpress`)
- **X (Formerly Twitter)** (`n8n-nodes-base.twitter`)

## Miscellaneous

- **** (`n8n-nodes-base.`)
- **DHL** (`n8n-nodes-base.dhl`)
- **Figma Trigger (Beta)** (`n8n-nodes-base.figmaTrigger`) (trigger)
- **Home Assistant** (`n8n-nodes-base.homeAssistant`)
- **Jina AI** (`n8n-nodes-base.jinaAi`)
- **LingvaNex** (`n8n-nodes-base.lingvaNex`)
- **NASA** (`n8n-nodes-base.nasa`)
- **Onfleet** (`n8n-nodes-base.onfleet`)
- **OpenWeatherMap** (`n8n-nodes-base.openWeatherMap`)
- **Philips Hue** (`n8n-nodes-base.philipsHue`)
- **Workable Trigger** (`n8n-nodes-base.workableTrigger`) (trigger)

## Productivity

- **Acuity Scheduling Trigger** (`n8n-nodes-base.acuitySchedulingTrigger`) (trigger)
- **Airtop** (`n8n-nodes-base.airtop`)
- **Asana** (`n8n-nodes-base.asana`)
- **Asana Trigger** (`n8n-nodes-base.asanaTrigger`) (trigger)
- **Beeminder** (`n8n-nodes-base.beeminder`)
- **Bitbucket Trigger** (`n8n-nodes-base.bitbucketTrigger`) (trigger)
- **Cal.com Trigger** (`n8n-nodes-base.calTrigger`) (trigger)
- **Calendly Trigger** (`n8n-nodes-base.calendlyTrigger`) (trigger)
- **ClickUp** (`n8n-nodes-base.clickUp`)
- **ClickUp Trigger** (`n8n-nodes-base.clickUpTrigger`) (trigger)
- **Clockify** (`n8n-nodes-base.clockify`)
- **Clockify Trigger** (`n8n-nodes-base.clockifyTrigger`) (trigger)
- **Coda** (`n8n-nodes-base.coda`)
- **CoinGecko** (`n8n-nodes-base.coinGecko`)
- **Flow** (`n8n-nodes-base.flow`)
- **Flow Trigger** (`n8n-nodes-base.flowTrigger`) (trigger)
- **Freshservice** (`n8n-nodes-base.freshservice`)
- **Harvest** (`n8n-nodes-base.harvest`)
- **Jira Software** (`n8n-nodes-base.jira`)
- **Jira Trigger** (`n8n-nodes-base.jiraTrigger`) (trigger)
- **Linear** (`n8n-nodes-base.linear`)
- **Linear Trigger** (`n8n-nodes-base.linearTrigger`) (trigger)
- **Monday.com** (`n8n-nodes-base.mondayCom`)
- **Notion Trigger** (`n8n-nodes-base.notionTrigger`) (trigger)
- **Oura** (`n8n-nodes-base.oura`)
- **Pushcut** (`n8n-nodes-base.pushcut`)
- **Raindrop** (`n8n-nodes-base.raindrop`)
- **ServiceNow** (`n8n-nodes-base.serviceNow`)
- **Strava** (`n8n-nodes-base.strava`)
- **Strava Trigger** (`n8n-nodes-base.stravaTrigger`) (trigger)
- **Taiga** (`n8n-nodes-base.taiga`)
- **Taiga Trigger** (`n8n-nodes-base.taigaTrigger`) (trigger)
- **Toggl Trigger** (`n8n-nodes-base.togglTrigger`) (trigger)
- **Trello** (`n8n-nodes-base.trello`)
- **Trello Trigger** (`n8n-nodes-base.trelloTrigger`) (trigger)
- **Twake** (`n8n-nodes-base.twake`)
- **Wekan** (`n8n-nodes-base.wekan`)
- **iCalendar** (`n8n-nodes-base.iCal`)

## Sales

- **Action Network** (`n8n-nodes-base.actionNetwork`)
- **Affinity** (`n8n-nodes-base.affinity`)
- **Affinity Trigger** (`n8n-nodes-base.affinityTrigger`) (trigger)
- **Agile CRM** (`n8n-nodes-base.agileCrm`)
- **Brandfetch** (`n8n-nodes-base.Brandfetch`)
- **Clearbit** (`n8n-nodes-base.clearbit`)
- **ConvertKit** (`n8n-nodes-base.convertKit`)
- **ConvertKit Trigger** (`n8n-nodes-base.convertKitTrigger`) (trigger)
- **Copper** (`n8n-nodes-base.copper`)
- **Copper Trigger** (`n8n-nodes-base.copperTrigger`) (trigger)
- **Drift** (`n8n-nodes-base.drift`)
- **Dropcontact** (`n8n-nodes-base.dropcontact`)
- **Eventbrite Trigger** (`n8n-nodes-base.eventbriteTrigger`) (trigger)
- **Freshworks CRM** (`n8n-nodes-base.freshworksCrm`)
- **Gumroad Trigger** (`n8n-nodes-base.gumroadTrigger`) (trigger)
- **HubSpot** (`n8n-nodes-base.hubspot`)
- **HubSpot Trigger** (`n8n-nodes-base.hubspotTrigger`) (trigger)
- **Hunter** (`n8n-nodes-base.hunter`)
- **Intercom** (`n8n-nodes-base.intercom`)
- **Keap** (`n8n-nodes-base.keap`)
- **Keap Trigger** (`n8n-nodes-base.keapTrigger`) (trigger)
- **LoneScale** (`n8n-nodes-base.loneScale`)
- **LoneScale Trigger** (`n8n-nodes-base.loneScaleTrigger`) (trigger)
- **Magento 2** (`n8n-nodes-base.magento2`)
- **Paddle** (`n8n-nodes-base.paddle`)
- **PayPal** (`n8n-nodes-base.payPal`)
- **PayPal Trigger** (`n8n-nodes-base.payPalTrigger`) (trigger)
- **Phantombuster** (`n8n-nodes-base.phantombuster`)
- **Pipedrive Trigger** (`n8n-nodes-base.pipedriveTrigger`) (trigger)
- **Salesforce** (`n8n-nodes-base.salesforce`)
- **Salesforce Trigger** (`n8n-nodes-base.salesforceTrigger`) (trigger)
- **Salesmate** (`n8n-nodes-base.salesmate`)
- **Shopify** (`n8n-nodes-base.shopify`)
- **Shopify Trigger** (`n8n-nodes-base.shopifyTrigger`) (trigger)
- **Stripe** (`n8n-nodes-base.stripe`)
- **Stripe Trigger** (`n8n-nodes-base.stripeTrigger`) (trigger)
- **Tapfiliate** (`n8n-nodes-base.tapfiliate`)
- **Unleashed Software** (`n8n-nodes-base.unleashedSoftware`)
- **Uplead** (`n8n-nodes-base.uplead`)
- **WooCommerce** (`n8n-nodes-base.wooCommerce`)
- **WooCommerce Trigger** (`n8n-nodes-base.wooCommerceTrigger`) (trigger)
- **Zoho CRM** (`n8n-nodes-base.zohoCrm`)

## Utility

- **Bitly** (`n8n-nodes-base.bitly`)
- **Brandfetch** (`n8n-nodes-base.Brandfetch`)
- **Cal.com Trigger** (`n8n-nodes-base.calTrigger`) (trigger)
- **Calendly Trigger** (`n8n-nodes-base.calendlyTrigger`) (trigger)
- **Clockify Trigger** (`n8n-nodes-base.clockifyTrigger`) (trigger)
- **DeepL** (`n8n-nodes-base.deepL`)
- **Mailcheck** (`n8n-nodes-base.mailcheck`)
- **Mindee** (`n8n-nodes-base.mindee`)
- **Mistral AI** (`n8n-nodes-base.mistralAi`)
- **One Simple API** (`n8n-nodes-base.oneSimpleApi`)
- **OpenThesaurus** (`n8n-nodes-base.openThesaurus`)
- **OpenWeatherMap** (`n8n-nodes-base.openWeatherMap`)
- **Perplexity** (`n8n-nodes-base.perplexity`)
- **Stop and Error** (`n8n-nodes-base.stopAndError`)
- **Toggl Trigger** (`n8n-nodes-base.togglTrigger`) (trigger)
- **Yourls** (`n8n-nodes-base.yourls`)
- **urlscan.io** (`n8n-nodes-base.urlScanIo`)

## Trigger Nodes

- **AMQP Trigger** (`n8n-nodes-base.amqpTrigger`)
- **ActiveCampaign Trigger** (`n8n-nodes-base.activeCampaignTrigger`)
- **Acuity Scheduling Trigger** (`n8n-nodes-base.acuitySchedulingTrigger`)
- **Affinity Trigger** (`n8n-nodes-base.affinityTrigger`)
- **Airtable Trigger** (`n8n-nodes-base.airtableTrigger`)
- **Asana Trigger** (`n8n-nodes-base.asanaTrigger`)
- **Autopilot Trigger** (`n8n-nodes-base.autopilotTrigger`)
- **Bitbucket Trigger** (`n8n-nodes-base.bitbucketTrigger`)
- **Box Trigger** (`n8n-nodes-base.boxTrigger`)
- **Brevo Trigger** (`n8n-nodes-base.sendInBlueTrigger`)
- **Cal.com Trigger** (`n8n-nodes-base.calTrigger`)
- **Calendly Trigger** (`n8n-nodes-base.calendlyTrigger`)
- **Chargebee Trigger** (`n8n-nodes-base.chargebeeTrigger`)
- **ClickUp Trigger** (`n8n-nodes-base.clickUpTrigger`)
- **Clockify Trigger** (`n8n-nodes-base.clockifyTrigger`)
- **ConvertKit Trigger** (`n8n-nodes-base.convertKitTrigger`)
- **Copper Trigger** (`n8n-nodes-base.copperTrigger`)
- **Cron** (`n8n-nodes-base.cron`)
- **Currents Trigger** (`n8n-nodes-base.currentsTrigger`)
- **Customer.io Trigger** (`n8n-nodes-base.customerIoTrigger`)
- **Emelia Trigger** (`n8n-nodes-base.emeliaTrigger`)
- **Error Trigger** (`n8n-nodes-base.errorTrigger`)
- **Eventbrite Trigger** (`n8n-nodes-base.eventbriteTrigger`)
- **Facebook Lead Ads Trigger** (`n8n-nodes-base.facebookLeadAdsTrigger`)
- **Facebook Trigger** (`n8n-nodes-base.facebookTrigger`)
- **Figma Trigger (Beta)** (`n8n-nodes-base.figmaTrigger`)
- **Flow Trigger** (`n8n-nodes-base.flowTrigger`)
- **Form.io Trigger** (`n8n-nodes-base.formIoTrigger`)
- **Formstack Trigger** (`n8n-nodes-base.formstackTrigger`)
- **GetResponse Trigger** (`n8n-nodes-base.getResponseTrigger`)
- **GitHub** (`n8n-nodes-base.github`)
- **GitLab Trigger** (`n8n-nodes-base.gitlabTrigger`)
- **Github Trigger** (`n8n-nodes-base.githubTrigger`)
- **Gumroad Trigger** (`n8n-nodes-base.gumroadTrigger`)
- **Help Scout Trigger** (`n8n-nodes-base.helpScoutTrigger`)
- **HubSpot Trigger** (`n8n-nodes-base.hubspotTrigger`)
- **Interval** (`n8n-nodes-base.interval`)
- **Invoice Ninja Trigger** (`n8n-nodes-base.invoiceNinjaTrigger`)
- **Jira Trigger** (`n8n-nodes-base.jiraTrigger`)
- **Jotform Trigger** (`n8n-nodes-base.jotFormTrigger`)
- **Kafka Trigger** (`n8n-nodes-base.kafkaTrigger`)
- **Keap Trigger** (`n8n-nodes-base.keapTrigger`)
- **KoBoToolbox Trigger** (`n8n-nodes-base.koBoToolboxTrigger`)
- **Linear Trigger** (`n8n-nodes-base.linearTrigger`)
- **LoneScale Trigger** (`n8n-nodes-base.loneScaleTrigger`)
- **MCP Server Trigger** (`@n8n/n8n-nodes-langchain.mcpTrigger`)
- **Mailchimp Trigger** (`n8n-nodes-base.mailchimpTrigger`)
- **Mailjet Trigger** (`n8n-nodes-base.mailjetTrigger`)
- **Manual Chat Trigger** (`@n8n/n8n-nodes-langchain.manualChatTrigger`)
- **Manual Trigger** (`n8n-nodes-base.manualTrigger`)
- **Mautic Trigger** (`n8n-nodes-base.mauticTrigger`)
- **Netlify Trigger** (`n8n-nodes-base.netlifyTrigger`)
- **Notion Trigger** (`n8n-nodes-base.notionTrigger`)
- **PayPal Trigger** (`n8n-nodes-base.payPalTrigger`)
- **Pipedrive Trigger** (`n8n-nodes-base.pipedriveTrigger`)
- **Postgres Trigger** (`n8n-nodes-base.postgresTrigger`)
- **Postmark Trigger** (`n8n-nodes-base.postmarkTrigger`)
- **Pushcut Trigger** (`n8n-nodes-base.pushcutTrigger`)
- **RSS Feed Trigger** (`n8n-nodes-base.rssFeedReadTrigger`)
- **Redis Trigger** (`n8n-nodes-base.redisTrigger`)
- **SSE Trigger** (`n8n-nodes-base.sseTrigger`)
- **Salesforce Trigger** (`n8n-nodes-base.salesforceTrigger`)
- **Schedule Trigger** (`n8n-nodes-base.scheduleTrigger`)
- **Shopify Trigger** (`n8n-nodes-base.shopifyTrigger`)
- **Slack Trigger** (`n8n-nodes-base.slackTrigger`)
- **Strava Trigger** (`n8n-nodes-base.stravaTrigger`)
- **Stripe Trigger** (`n8n-nodes-base.stripeTrigger`)
- **SurveyMonkey Trigger** (`n8n-nodes-base.surveyMonkeyTrigger`)
- **Taiga Trigger** (`n8n-nodes-base.taigaTrigger`)
- **Telegram Trigger** (`n8n-nodes-base.telegramTrigger`)
- **TheHive 5 Trigger** (`n8n-nodes-base.theHiveProjectTrigger`)
- **TheHive Trigger** (`n8n-nodes-base.theHiveTrigger`)
- **Toggl Trigger** (`n8n-nodes-base.togglTrigger`)
- **Trello Trigger** (`n8n-nodes-base.trelloTrigger`)
- **Twilio Trigger** (`n8n-nodes-base.twilioTrigger`)
- **Typeform Trigger** (`n8n-nodes-base.typeformTrigger`)
- **Webflow Trigger** (`n8n-nodes-base.webflowTrigger`)
- **WhatsApp Trigger** (`n8n-nodes-base.whatsAppTrigger`)
- **Wise Trigger** (`n8n-nodes-base.wiseTrigger`)
- **WooCommerce Trigger** (`n8n-nodes-base.wooCommerceTrigger`)
- **Workable Trigger** (`n8n-nodes-base.workableTrigger`)
- **Wufoo Trigger** (`n8n-nodes-base.wufooTrigger`)
- **Zendesk Trigger** (`n8n-nodes-base.zendeskTrigger`)
- **n8n Form** (`n8n-nodes-base.form`)

## AI / LangChain Nodes

- **Basic LLM Chain** (`@n8n/n8n-nodes-langchain.chainLlm`)
- **Chat Memory Manager** (`@n8n/n8n-nodes-langchain.memoryManager`)
- **Chat Messages Retriever** (`@n8n/n8n-nodes-langchain.memoryChatRetriever`)
- **Contextual Compression Retriever** (`@n8n/n8n-nodes-langchain.retrieverContextualCompression`)
- **Default Data Loader** (`@n8n/n8n-nodes-langchain.documentDefaultDataLoader`)
- **In Memory Vector Store Insert** (`@n8n/n8n-nodes-langchain.vectorStoreInMemoryInsert`)
- **In Memory Vector Store Load** (`@n8n/n8n-nodes-langchain.vectorStoreInMemoryLoad`)
- **MCP Server Trigger** (`@n8n/n8n-nodes-langchain.mcpTrigger`)
- **MultiQuery Retriever** (`@n8n/n8n-nodes-langchain.retrieverMultiQuery`)
- **OpenAI Assistant** (`@n8n/n8n-nodes-langchain.openAiAssistant`)
- **OpenAI Model** (`@n8n/n8n-nodes-langchain.lmOpenAi`)
- **Vector Store Retriever** (`@n8n/n8n-nodes-langchain.retrieverVectorStore`)
- **Workflow Retriever** (`@n8n/n8n-nodes-langchain.retrieverWorkflow`)
- **Zep Vector Store: Insert** (`@n8n/n8n-nodes-langchain.vectorStoreZepInsert`)

## Uncategorized

- **Currents** (`n8n-nodes-base.currents`)
- **Currents Trigger** (`n8n-nodes-base.currentsTrigger`)
- **Customer Datastore (n8n training)** (`n8n-nodes-base.n8nTrainingCustomerDatastore`)
- **Customer Messenger (n8n training)** (`n8n-nodes-base.n8nTrainingCustomerMessenger`)
